- UserID
ID
- Inventory_Date
Date of data collection
- Species
Species of the tree. All dead trees were listed as "unknown"
- Common_Name
Common name of the tree
- DBH
Diameter at breast height (4.5' above ground)
- Condition
Trees were rated as good, fair, poor, or dead.
These general ratings reflect whether or not a tree is likely to
continue contributing to the urban forest (good and fair trees)
or whether the tree is at or near the end of its life (poor and dead trees).
- Site_Type
Where along the street the tree was located.
There are 8 different site types and more info can be found here:
https://gis-pdx.opendata.arcgis.com/datasets/PDX::street-tree-inventory-active-records/about
- Site_Size
Categorical size of the site: Small, Medium, Large
- Site_Width
How wide the site was in ft.
- Wires
Whether or not the site had wires: High voltage,
No High voltage (No HV), other
- Site_Development
The condition of the site either being improved
(ex. along a side walk or paved roadway ) or unimproved (a gravel road))
- Address
The address where the tree is located
- Neighborhood
The Portland neighborhood in which the tree is located
- Collected_By
Who collected the data on this tree: staff or volunteer
- Scientific
Scientific name of the tree
- Family
Family of the tree
- Genus
Genus of the tree
- Functional_Type
Categorical variable with groups:
Broadleaf Deciduous (BD), Broadleaf Evergreen (BE),
Coniferous Deciduous (CD), and Coniferous Evergreen (CE)
- Mature_Size
Categorical variable with groups: Large (L),
Medium (M), and Small (S). Categorization is based on the height,
canopy width, and general form of the tree at maturity
- Edible
Categorical variable of edible trees
- Notes
Note on the data collection
- Longitude
Longitude
- Latitude
Latitude